#
# spec file for package thin-provisioning-tools
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           thin-provisioning-tools
VCS: https://src.suse.de/SLFO-pool/thin-provisioning-tools#4c704fe9b228f2b4c9d683cc9a161d4d3a87c2e26038a98b9767d3d58b1885f3
Version:        1.1.0
Release:        160000.1.2
Summary:        Thin Provisioning Tools
License:        GPL-3.0-only
URL:            https://github.com/jthornber/thin-provisioning-tools/
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  clang-devel
BuildRequires:  device-mapper-devel
BuildRequires:  pkgconfig
BuildRequires:  suse-module-tools
BuildRequires:  pkgconfig(libudev)
Requires(post): coreutils
Requires(postun): coreutils
Conflicts:      device-mapper < 1.02.115

%description
A suite of tools for thin provisioning on Linux.

%prep
%autosetup -a1

%build
%{cargo_build}

%install
make install STRIP="/bin/true" MANPATH=%{buildroot}%{_mandir} BINDIR=%{buildroot}%{_sbindir}

%check
%{cargo_test}

%post
%{?regenerate_initrd_post}

%postun
%{?regenerate_initrd_post}

%posttrans
%{?regenerate_initrd_posttrans}

%files
%doc README.md
%license COPYING
%{_sbindir}/cache_check
%{_sbindir}/cache_dump
%{_sbindir}/cache_metadata_size
%{_sbindir}/cache_repair
%{_sbindir}/cache_restore
%{_sbindir}/cache_writeback
%{_sbindir}/era_check
%{_sbindir}/era_dump
%{_sbindir}/era_invalidate
%{_sbindir}/era_restore
%{_sbindir}/pdata_tools
%{_sbindir}/thin_check
%{_sbindir}/thin_delta
%{_sbindir}/thin_dump
%{_sbindir}/thin_ls
%{_sbindir}/thin_metadata_pack
%{_sbindir}/thin_metadata_size
%{_sbindir}/thin_metadata_unpack
%{_sbindir}/thin_migrate
%{_sbindir}/thin_repair
%{_sbindir}/thin_restore
%{_sbindir}/thin_rmap
%{_sbindir}/thin_trim
%{_mandir}/man8/cache_check.8%{?ext_man}
%{_mandir}/man8/cache_dump.8%{?ext_man}
%{_mandir}/man8/cache_metadata_size.8%{?ext_man}
%{_mandir}/man8/cache_repair.8%{?ext_man}
%{_mandir}/man8/cache_restore.8%{?ext_man}
%{_mandir}/man8/cache_writeback.8%{?ext_man}
%{_mandir}/man8/era_check.8%{?ext_man}
%{_mandir}/man8/era_dump.8%{?ext_man}
%{_mandir}/man8/era_invalidate.8%{?ext_man}
%{_mandir}/man8/era_restore.8%{?ext_man}
%{_mandir}/man8/thin_check.8%{?ext_man}
%{_mandir}/man8/thin_delta.8%{?ext_man}
%{_mandir}/man8/thin_dump.8%{?ext_man}
%{_mandir}/man8/thin_ls.8%{?ext_man}
%{_mandir}/man8/thin_metadata_pack.8%{?ext_man}
%{_mandir}/man8/thin_metadata_size.8%{?ext_man}
%{_mandir}/man8/thin_metadata_unpack.8%{?ext_man}
%{_mandir}/man8/thin_migrate.8%{?ext_man}
%{_mandir}/man8/thin_repair.8%{?ext_man}
%{_mandir}/man8/thin_restore.8%{?ext_man}
%{_mandir}/man8/thin_rmap.8%{?ext_man}
%{_mandir}/man8/thin_trim.8%{?ext_man}

%changelog
* Tue Feb 18 2025 mpluskal@suse.com
- Enable internal testsuite
- Refresh vendored dependencies
* Mon Feb 10 2025 glass.su@suse.com
- thin-provisioning-tools lacks symlinks and related man pages (boo#1236800)
  * Call make install to generate symbolic links of comamnds
  * Update %%files section to include above symbolic links and man
* Wed Aug 28 2024 mpluskal@suse.com
- Update to version 1.1.0:
  * Bump version to 1.1.0
  * [doc] Update CHANGES
  * [build] Update dependencies
  * [thin_migrate] Tweak the checking routines
  * [thin_migrate] Enforce that the source device be read-only
  * [thin_migrate] Do not open the source device exclusively
  * [man] Update thin_migrate man page
  * [man] Update thin_dump man page
  * v1.0.14
  * [doc] Update CHANGES
  * [build] Update Makefile to install thin_migrate
  * [build] Update dependencies
  * [thin_migrate] Check file type of the output device
  * [thin_migrate] Fix suspicious open options suggested by clippy
  * [doc] Update links in GPLv3
  * [file_utils] Remove unexpected target_arch 'powerpc64le'
  * [man] Fix the buffer size descriptions for cache_writeback
  * [doc] Update TODO list
  * [doc] Fix typos
  * [man] Fix man page formatting
  * [man] Add man page for thin_migrate
  * [thin_migrate] Fix file size check on the output file
  * [thin_migrate] Add progress bar
  * [copier] Make the ProgressReporter reusable
  * [thin_migrate] Update devicemapper-rs registry
  * [thin_migrate] Hide unimplemented delta-id option and related code
  * [thin_migrate] Remove unused code
  * [thin_migrate] Hide unused --zero-dest option
  * [thin_migrate] Tweak the value names in help text
  * [thin_migrate] Fix buffer size settings for the copier
  * [thin_migrate] Use direct io for better performance and error handling
  * [copier] Factor out common code
  * [space_map] Improve error tolerance of ref counting
  * [thin_check] Fix overriding roots not working if the original one broke
  * [thin_migrate] Apply cargo fmt, and fix clippy lints
  * [thin_migrate] Remove unused functions and fields
  * [thin_migrate] Fix copier parameters
  * [thin_migrate] Fix mapping stream outputs
  * [thin_migrate] Fix getting block device file size
  * [thin_migrate] Temporarily skip progress display
  * [thin_migrate] Fix opening pool metadata exclusively
  * Builds but not tested yet
  * wip
  * [thin_migrate] wip
  * [thin_migrate] work in progress
  * [btree] add lookup function
  * [thin_migrate] wip
* Mon Jul 22 2024 mpluskal@suse.com
- Update to version 1.0.13:
  * bump version to 1.0.13
  * [io_engine] Remove duplicate code in tests
  * [build] Update quick-xml to v0.36
  * [build] Update dependencies
  * [doc] Update CHANGES
  * [thin_check] Correct the number of devices to check in logs
  * [doc] Update TODO list
  * [man] Update man page for thin_ls
  * [io_engine] Add test cases for SyncIoEngine::write_many()
  * [io_engine] Enlarge the batch size for SyncIoEngine to do vectored write
  * [io_engine] Use vectored write in sync io
  * [tests] Use sha256sum to avoid collision
  * [all] Fix clippy lints
  * [tests] Fix thin snapshot xml generator
  * [tests] Fix the mapped_blocks for thins in generated xml
  * [thin_check] Log the number of exclusive devices in metadata snapshot
  * [devtools] Fix parsing subcommands through symlinks
  * deps: bump libc from 0.2.153 to 0.2.155
  * [thin_repair] Support repairing device details tree
  * [tests] Replace duplicate code with utility functions
  * [thin_repair] Remove unused code
  * [thin_repair] Preserve the timestamp of stale superblock if needed
  * [thin_explore] Fix missing version option
  * Add a nix flake to provide a dev env
  * [thin_delta] Update comments
  * [tests] Test cache_check --auto-repair and --clear-needs-check-flag
  * [tests] Introduce cache_generate_damage
  * [tests] Add broken pipe tests for cache_dump and era_dump
  * [cache_check] Extend the --clear-needs-check-flag option to have auto-repair caps
  * [thin_ls] Support listing the highest mapped block
  * [btree] Remove unused imports
  * [btree] Add BTreeIterator type
  * [*_dump] Simplify the handling of error context
  * [cache/era_dump] Do not print error messages on BrokenPipe (EPIPE)
  * [tests] Explicitly set the fifo capacity for triggering EPIPE
  * [tests] Support leaving TestDir undeleted for debugging failed commands
  * [tests] Ensure thin_dump's output in broken pipe tests
  * [tests] Fix closing the pipe fd twice
  * [tests] Explicitly set the pipe capacity for triggering EPIPE
* Tue Apr 23 2024 mpluskal@suse.com
- Update vendored dependencies
* Fri Mar 22 2024 mpluskal@suse.com
- Enable test execution during build
- Modernise cargo packaging usage in spec file
* Mon Feb 26 2024 mpluskal@suse.com
- Update to version 1.0.12:
  * [thin_dump] Do not print error messages on BrokenPipe (EPIPE)
  * Bump version to 1.0.12
  * [build] Update dependencies
  * [commands] Fix version string compatibility issue with LVM
  * [thin_dump] Do not print error messages on BrokenPipe (EPIPE)
  * [build] Update license to SPDX identifier
* Tue Feb 13 2024 mpluskal@suse.com
- Update to version 1.0.11:
  * Bump version nr to 1.0.11
  * [thin/cache_check] Print suggestive hints for improving error resolution
  * [tests] Fix a typo in command name
  * [cache_check] Fix boundary check on the bitset for cached blocks
* Wed Jan 24 2024 mpluskal@suse.com
- Update to version 1.0.10:
  * Bump version to 1.0.10
  * [build] Update dependencies
  * [all] Fix clippy lints and typos
  * [space_map] Allow non-zero values in unused index block entries
  * [thin_repair] Fix child keys checking on the node with a zero key
  * [thin_check] Tweak the logs to avoid confusion with node errors
  * [thin_check] Support overriding the details tree root
  * [tests] Update expected help text for _pack and _unpack
  * [all] Fix clippy lints on optional targets
  * [build] Simplify the pre-commit hooks by checking all the targets at once
  * [thin_metadata_unpack] Allow long format for input and output
  * [space map] Fix incorrect index_entry.nr_free while expansion
  * thin_metadata_pack: Allow long format for input and output
* Mon Dec 18 2023 mpluskal@suse.com
- Update to version 1.0.9:
  * Update Cargo.lock
  * [build] Check Cargo.lock while it is updated
  * Bump version to 1.0.9
  * [build] Sync dependencies versions between Cargo.lock and Cargo.toml
  * [thin_check] Extend the --clear-needs-check-flag option to have auto-repair caps
  * [build] Require that Cargo.lock is up to date
  * [all] Fix clippy lints for Rust 1.74.0
  * Update cargo.lock
  * bump version nr to 1.0.8
  * [sync io engine] Stop reusing the same gap buffer.
  * [tests] Fix extra arguments for IO tests
* Tue Nov 28 2023 mpluskal@suse.com
- Update vendored dependencies
* Tue Nov 14 2023 mpluskal@suse.com
- Update to version 1.0.7:
  * v1.0.7
  * [thin_generate_metadata] Fix command line parsing
  * [tests] Introduce era_generate_metadata
  * [era] Factor out MetadataGenerator
  * [era_invalidate] Fix missing value_parser for the --written-since option
  * [tests] Support additional program-specific arguments in IO tests
  * [examples] Add a custom emitter examples
  * Remove unnecesary type casting
  * [file_utils] Verify ioctl request code in tests
  * [file_utils] Fix the ioctl request code for the powerpc architecture
  * bump version to 1.0.6
  * [build] Update dependencies
  * [thin_delta] Remove redundant code
  * [thin_delta] Fix range mappings construction
  * [thin_delta] Fix command line parsing
  * [pack/unpack] Fix clippy lints
  * Bump version to v1.05
  * Add some test cases to delta_list
  * [pack/unpack]  Fix some wrapping issues
  * [tests] Ensure the scope of thin_check --super-block-only
  * [tests] Test repairing thin metadata with stale superblock
  * [thin_generate_damage] Support overriding superblock fields
  * [tests] Validate more fields in repaired thin superblock
  * [thin_explore] Fix visiting empty leaves
  * [xml] Improve xml value parsing and error handling
  * [all] Update error messages for xml parsers
  * [build] Update quick-xml to v0.29
  * [build] Update clap to v4.3
  * [build] Update dependencies
  * [thin_rmap] Check the input ranges
  * [thin_dump/repair] Fix the ordering of found empty roots
  * [report] Fix stderr redirection
  * [thin_dump/repair] Ensure the tools never fail with repairable metadata
  * [build] allow overriding PDATA_TOOLS in Makefile
  * [build] fix build on musl
  * [thin_stat] Display column headers and further statistics
  * [thin_stat] Display data run length statistics for measuring data locality
  * [thin_explore] Fix unit conversion for data block size
  * [thin_explore] Display space maps usage and roots
  * [thin_stat] Fix opening read-only files
  * [thin_dump] Fix a regression that cannot keep shared defs with only one predecessor
  * [commands] Print out error root cause if available
* Fri Jun  9 2023 mpluskal@suse.com
- Update to version 1.0.4:
  * Bump version to 1.0.4
  * [build] Update dependencies
  * [all] Fix clippy lints for Rust 1.69.0
  * [build] Drop the nix crate
  * [file_utils] Fix the BLKGETSIZE64 ioctl for 32-bit platoforms
  * [file_utils] Use stat64 explicitly to handle large files on 32-bit systems
  * [write_batcher] Fix compilation error on 32-bit platforms
* Wed Jun  9 2021 wolfgang.frisch@suse.com
- Link as position-independent executable (bsc#1184124).
* Thu Aug 20 2020 mpluskal@suse.com
- Update to version 0.9.0:
  * New support tools: thin_metadata_{pack,unpack}.
  * thin_check can now check metadata snapshots.
  * some metadata space map bug fixes.
  * thin_check --auto-repair
  * Stop thin_dump --repair/thin_repair ignoring under populated nodes.
- Drop no longer needed patches:
  * boost_168.patch
  * ft-lib_bcache-rename-raise-raise_.patch
* Tue Aug 13 2019 mpluskal@suse.com
- Update to version 0.8.5
  * Mostly internal changes
* Mon Aug  5 2019 stefan.bruens@rwth-aachen.de
- Fix name clash with raise() from signal.h, add
  ft-lib_bcache-rename-raise-raise_.patch
* Wed May 29 2019 mpluskal@suse.com
- Update to version 0.8.3:
  * Mostly internal changes
* Fri Aug 17 2018 adam.majer@suse.de
- boost_168.patch: fix build with Boost 1.68. This version of Boost
  removes compatibility SHA1 header from Uuid library. (bsc#1105088)
* Thu May 31 2018 mpluskal@suse.com
- Update to version 0.7.6:
  * Mostly internal changes
* Wed Mar 14 2018 mpluskal@suse.com
- Modernise spec file with spec-cleaner
* Wed Dec  6 2017 mpluskal@suse.com
- Update to version 0.7.5:
  * Fix a bug that stopped cache_restore working with metadata
    version 2.
* Tue Oct 17 2017 mpluskal@suse.com
- Update to version 0.7.4:
  * No changes provided for this release
* Mon Oct  9 2017 mpluskal@suse.com
- Update to version 0.7.3:
  * Misc internal changes
  * Updates to tests
* Mon Oct  2 2017 mpluskal@suse.com
- Update to version 0.7.2:
  * Misc internal changes
  * Updated documentation and manpages
* Tue Sep  5 2017 mpluskal@suse.com
- Update to version 0.7.1:
  * Misc internal changes
- Enable development tools building
* Mon Aug 28 2017 mmarek@suse.com
- Depend on coreutils for initrd macros (bsc#1055492).
* Sun Jun 18 2017 mpluskal@suse.com
- Update dependencies of scriplets (boo#1044823)
* Mon Jun 12 2017 mpluskal@suse.com
- Update to version 0.7.0:
  * boo#1043043 gh#jthornber/thin-provisioning-tools#79
  * Needed for working with latest lvm2
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Aug 18 2016 mpluskal@suse.com
- Update to version 0.6.3:
  * Update documentation
* Sun Jul 10 2016 mpluskal@suse.com
- Update to version 0.6.2:
  * Fix bug in thin_delta
  * Fix recent regression in thin_repair.
  * Force g++-98 dialect
  * Fix bug in thin_trim
* Thu Feb 11 2016 rguenther@suse.com
- Explicitely build with -std=gnu++98 to avoid all sorts of
  non-C++11 conforming code.
* Sat Feb  6 2016 mpluskal@suse.com
- Update to 0.6.1
  * enable builds with static cxx library
- Make building more verbose
* Fri Jan 29 2016 mpluskal@suse.com
- Conflict with device-mapper < 1.02.115 to avoid file conflicts
* Sun Jan 24 2016 mpluskal@suse.com
- Use optflags when building
- Install to /usr/sbin
- Do not strip installed binaries
- Use scriplets for initrd regeneration
* Fri Jan 22 2016 mpluskal@suse.com
- Update to 0.6.0
  * thin_ls
* Sun Sep 20 2015 mpluskal@suse.com
- Update to 0.5.6
  * era_invalidate may be run on live metadata if the
  - -metadata-snap option is given.
- Changes for 0.5.5
  * You may now give the --metadata_snap option to thin_delta
    without specifying where the snap is.
  * Update man pages to make it clearer that most tools shouldn't
    be run on live metadata.
  * Fix some bugs in the metadata reference counting for
    thin_check.
* Tue Jul 28 2015 mpluskal@suse.com
- Update to 0.5.3
  * thin_delta, thin_trim
  * --clear-needs-check flag for cache_check
  * space map checking for thin check
* Thu Apr 23 2015 mpluskal@suse.com
- Update to 0.4.1
* Wed Feb  6 2013 martin@pluskal.org
- Cleanup .spec
* Wed Feb  6 2013 martin@pluskal.org
- Add patch for ldflags - ldflags.patch
* Tue Jul 31 2012 fehr@suse.de
- Make initial version of package from version 0.1.5 of
  thin-provisioning-tools
